@@ -3,6 +3,7 @@
 import threading
 
 from masterful_gui.backend.apps.api import policy_search_task_scanner
+from masterful_gui.backend.apps.api import dataset_scanner
 
 # Interval for periodic scanning.
 _INTERVAL_SEC = 60.0
@@ -29,6 +30,7 @@ def _scan(reschedule: bool) -> None:
   """
   try:
     policy_search_task_scanner.scan()
+    dataset_scanner.scan()
   except Exception as e:
     print(f'Scanning for serialized protos failed: {str(e)}')
 
