@@ -10,8 +10,8 @@ class PolicySearchTaskModelSerializer(serializers.ModelSerializer):
     fields = '__all__'
 
 
-class DatasetSpecModelSerializer(serializers.ModelSerializer):
+class DatasetModelSerializer(serializers.ModelSerializer):
 
   class Meta:
-    model = models.DatasetSpec
+    model = models.Dataset
     fields = '__all__'
\ No newline at end of file
