@@ -4,7 +4,7 @@ from rest_framework import viewsets
 from masterful_gui.backend.apps.api import serializers
 from masterful_gui.backend.apps.api import models
 from masterful_gui.backend.apps.api import policy_search_task_scanner
-from masterful_gui.backend.apps.api import dataset_spec_scanner
+from masterful_gui.backend.apps.api import dataset_scanner
 
 
 class PolicySearchTaskView(viewsets.ReadOnlyModelViewSet):
@@ -12,9 +12,9 @@ class PolicySearchTaskView(viewsets.ReadOnlyModelViewSet):
   queryset = models.PolicySearchTask.objects.all()
 
 
-class DatasetSpecView(viewsets.ReadOnlyModelViewSet):
-  serializer_class = serializers.DatasetSpecModelSerializer
-  queryset = models.DatasetSpec.objects.all()
+class DatasetView(viewsets.ReadOnlyModelViewSet):
+  serializer_class = serializers.DatasetModelSerializer
+  queryset = models.Dataset.objects.all()
 
 
 def scan_view(request):
@@ -23,7 +23,7 @@ def scan_view(request):
   # a template. This is not required it's just for aesthetics.
   try:
     policy_search_task_scanner.scan()
-    dataset_spec_scanner.scan()
+    dataset_scanner.scan()
   except Exception as e:
     print(str(e))
     return http.HttpResponseServerError()
