@@ -17,16 +17,20 @@ from django.contrib import admin
 from django.urls import path, include
 from django.views.generic import TemplateView
 from rest_framework import routers
+from django.contrib.staticfiles.storage import staticfiles_storage
+from django.views.generic.base import RedirectView
 
 from masterful_gui.backend.apps.api import views
 
 router = routers.DefaultRouter()
 router.register(r'search', views.PolicySearchTaskView, 'search')
-router.register(r'dataset', views.DatasetSpecView, 'dataset')
+router.register(r'dataset', views.DatasetView, 'dataset')
 
 urlpatterns = [
     path('admin/', admin.site.urls),
     path('scan/', views.scan_view, name='scan'),
     path('api/', include(router.urls)),
     path('', TemplateView.as_view(template_name="index.html")),
+    path('favicon.ico',
+         RedirectView.as_view(url=staticfiles_storage.url('img/favicon.ico'))),
 ]
